@@ -1,27 +1,21 @@
+use 5.006;
 use strict;
 use warnings;
 
 package ELF::Extract::Sections::Meta::Scanner;
-BEGIN {
-  $ELF::Extract::Sections::Meta::Scanner::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $ELF::Extract::Sections::Meta::Scanner::VERSION = '0.03000101';
-}
 
 # ABSTRACT: Interface Contract for Scanners
 
-use MooseX::Declare;
+our $VERSION = '1.000000';
 
-role ELF::Extract::Sections::Meta::Scanner with MooseX::Log::Log4perl {
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
-    requires(
-        'open_file',      'next_section',
-        'section_offset', 'section_size',
-        'section_name',   'can_compute_size'
-    );
+use Moose::Role qw( with requires );
+with 'MooseX::Log::Log4perl';
 
-};
+requires( 'open_file', 'next_section', 'section_offset', 'section_size', 'section_name', 'can_compute_size' );
+
+no Moose::Role;
 
 1;
 
@@ -29,13 +23,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 ELF::Extract::Sections::Meta::Scanner - Interface Contract for Scanners
 
 =head1 VERSION
 
-version 0.03000101
+version 1.000000
 
 =head1 Required Methods for Applying Roles
 
@@ -75,7 +71,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric.
+This software is copyright (c) 2015 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
